// Copyright (c) Microsoft and contributors.  All rights reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// 
// See the License for the specific language governing permissions and
// limitations under the License.
// 
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is
// regenerated.

//
// This file was autogenerated by a tool.
// Do not modify it.
//

namespace Microsoft.Azure.Batch
{
    using Models = Microsoft.Azure.Batch.Protocol.Models;
    using System;
    using System.Collections.Generic;
    using System.Linq;

    /// <summary>
    /// Resource usage statistics for the task.
    /// </summary>
    public partial class TaskStatistics : IPropertyMetadata
    {
        private readonly TimeSpan kernelCpuTime;
        private readonly DateTime lastUpdateTime;
        private readonly double readIOGiB;
        private readonly long readIOps;
        private readonly DateTime startTime;
        private readonly string url;
        private readonly TimeSpan userCpuTime;
        private readonly TimeSpan waitTime;
        private readonly TimeSpan wallClockTime;
        private readonly double writeIOGiB;
        private readonly long writeIOps;

        #region Constructors

        internal TaskStatistics(Models.TaskStatistics protocolObject)
        {
            this.kernelCpuTime = protocolObject.KernelCPUTime;
            this.lastUpdateTime = protocolObject.LastUpdateTime;
            this.readIOGiB = protocolObject.ReadIOGiB;
            this.readIOps = protocolObject.ReadIOps;
            this.startTime = protocolObject.StartTime;
            this.url = protocolObject.Url;
            this.userCpuTime = protocolObject.UserCPUTime;
            this.waitTime = protocolObject.WaitTime;
            this.wallClockTime = protocolObject.WallClockTime;
            this.writeIOGiB = protocolObject.WriteIOGiB;
            this.writeIOps = protocolObject.WriteIOps;
        }

        #endregion Constructors

        #region TaskStatistics

        /// <summary>
        /// Gets the total kernel mode CPU time (per core) consumed by the task.
        /// </summary>
        public TimeSpan KernelCpuTime
        {
            get { return this.kernelCpuTime; }
        }

        /// <summary>
        /// Gets the time at which the statistics were last updated. All statistics are limited to the range between <see 
        /// cref="StartTime"/> and this value.
        /// </summary>
        public DateTime LastUpdateTime
        {
            get { return this.lastUpdateTime; }
        }

        /// <summary>
        /// Gets the total gibibytes of I/O read from disk by the task.
        /// </summary>
        public double ReadIOGiB
        {
            get { return this.readIOGiB; }
        }

        /// <summary>
        /// Gets the total number of disk read operations made by the task.
        /// </summary>
        public long ReadIOps
        {
            get { return this.readIOps; }
        }

        /// <summary>
        /// Gets the start time of the time range covered by the statistics.
        /// </summary>
        public DateTime StartTime
        {
            get { return this.startTime; }
        }

        /// <summary>
        /// Gets the URL of the task statistics.
        /// </summary>
        public string Url
        {
            get { return this.url; }
        }

        /// <summary>
        /// Gets the total user mode CPU time (per core) consumed by the task.
        /// </summary>
        public TimeSpan UserCpuTime
        {
            get { return this.userCpuTime; }
        }

        /// <summary>
        /// Gets the total wait time of the task. The wait time for a task is defined as the elapsed time between the creation 
        /// of the task and the start of task execution. (If the task is retried due to failures, the wait time is the time 
        /// to the most recent task execution.)
        /// </summary>
        public TimeSpan WaitTime
        {
            get { return this.waitTime; }
        }

        /// <summary>
        /// Gets the wall clock time of the task execution.
        /// </summary>
        public TimeSpan WallClockTime
        {
            get { return this.wallClockTime; }
        }

        /// <summary>
        /// Gets the total gibibytes of I/O written to disk by the task.
        /// </summary>
        public double WriteIOGiB
        {
            get { return this.writeIOGiB; }
        }

        /// <summary>
        /// Gets the total number of disk write operations made by the task.
        /// </summary>
        public long WriteIOps
        {
            get { return this.writeIOps; }
        }

        #endregion // TaskStatistics

        #region IPropertyMetadata

        bool IModifiable.HasBeenModified
        {
            //This class is compile time readonly so it cannot have been modified
            get { return false; }
        }

        bool IReadOnly.IsReadOnly
        {
            get { return true; }
            set
            {
                // This class is compile time readonly already
            }
        }

        #endregion // IPropertyMetadata
    }
}