// 
// Copyright (c) Microsoft and contributors.  All rights reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// 
// See the License for the specific language governing permissions and
// limitations under the License.
// 

// Warning: This code was generated by a tool.
// 
// Changes to this file may cause incorrect behavior and will be lost if the
// code is regenerated.

using System;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using Microsoft.Azure;
using Microsoft.Azure.Management.Automation;
using Microsoft.Azure.Management.Automation.Models;

namespace Microsoft.Azure.Management.Automation
{
    public static partial class DscNodeOperationsExtensions
    {
        /// <summary>
        /// Delete the dsc node identified by node id.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. Automation account name.
        /// </param>
        /// <param name='nodeId'>
        /// Required. The node id.
        /// </param>
        /// <returns>
        /// A standard service response including an HTTP status code and
        /// request ID.
        /// </returns>
        public static AzureOperationResponse Delete(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, Guid nodeId)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDscNodeOperations)s).DeleteAsync(resourceGroupName, automationAccount, nodeId);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// Delete the dsc node identified by node id.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. Automation account name.
        /// </param>
        /// <param name='nodeId'>
        /// Required. The node id.
        /// </param>
        /// <returns>
        /// A standard service response including an HTTP status code and
        /// request ID.
        /// </returns>
        public static Task<AzureOperationResponse> DeleteAsync(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, Guid nodeId)
        {
            return operations.DeleteAsync(resourceGroupName, automationAccount, nodeId, CancellationToken.None);
        }
        
        /// <summary>
        /// Retrieve the dsc node identified by node id.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. The automation account name.
        /// </param>
        /// <param name='nodeId'>
        /// Required. The node id.
        /// </param>
        /// <returns>
        /// The response model for the get dsc node operation.
        /// </returns>
        public static DscNodeGetResponse Get(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, Guid nodeId)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDscNodeOperations)s).GetAsync(resourceGroupName, automationAccount, nodeId);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// Retrieve the dsc node identified by node id.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. The automation account name.
        /// </param>
        /// <param name='nodeId'>
        /// Required. The node id.
        /// </param>
        /// <returns>
        /// The response model for the get dsc node operation.
        /// </returns>
        public static Task<DscNodeGetResponse> GetAsync(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, Guid nodeId)
        {
            return operations.GetAsync(resourceGroupName, automationAccount, nodeId, CancellationToken.None);
        }
        
        /// <summary>
        /// Retrieve a list of dsc nodes.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. The automation account name.
        /// </param>
        /// <param name='parameters'>
        /// Optional. The parameters supplied to the list operation.
        /// </param>
        /// <returns>
        /// The response model for the list dsc nodes operation.
        /// </returns>
        public static DscNodeListResponse List(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, DscNodeListParameters parameters)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDscNodeOperations)s).ListAsync(resourceGroupName, automationAccount, parameters);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// Retrieve a list of dsc nodes.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. The automation account name.
        /// </param>
        /// <param name='parameters'>
        /// Optional. The parameters supplied to the list operation.
        /// </param>
        /// <returns>
        /// The response model for the list dsc nodes operation.
        /// </returns>
        public static Task<DscNodeListResponse> ListAsync(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, DscNodeListParameters parameters)
        {
            return operations.ListAsync(resourceGroupName, automationAccount, parameters, CancellationToken.None);
        }
        
        /// <summary>
        /// Retrieve next list of configurations.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='nextLink'>
        /// Required. The link to retrieve next set of items.
        /// </param>
        /// <returns>
        /// The response model for the list dsc nodes operation.
        /// </returns>
        public static DscNodeListResponse ListNext(this IDscNodeOperations operations, string nextLink)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDscNodeOperations)s).ListNextAsync(nextLink);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// Retrieve next list of configurations.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='nextLink'>
        /// Required. The link to retrieve next set of items.
        /// </param>
        /// <returns>
        /// The response model for the list dsc nodes operation.
        /// </returns>
        public static Task<DscNodeListResponse> ListNextAsync(this IDscNodeOperations operations, string nextLink)
        {
            return operations.ListNextAsync(nextLink, CancellationToken.None);
        }
        
        /// <summary>
        /// Update the dsc node.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. The automation account name.
        /// </param>
        /// <param name='parameters'>
        /// Required. Parameters supplied to the patch dsc node.
        /// </param>
        /// <returns>
        /// The response model for the patch dsc node operation.
        /// </returns>
        public static DscNodePatchResponse Patch(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, DscNodePatchParameters parameters)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDscNodeOperations)s).PatchAsync(resourceGroupName, automationAccount, parameters);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// Update the dsc node.  (see
        /// http://aka.ms/azureautomationsdk/dscnodeoperations for more
        /// information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.Azure.Management.Automation.IDscNodeOperations.
        /// </param>
        /// <param name='resourceGroupName'>
        /// Required. The name of the resource group
        /// </param>
        /// <param name='automationAccount'>
        /// Required. The automation account name.
        /// </param>
        /// <param name='parameters'>
        /// Required. Parameters supplied to the patch dsc node.
        /// </param>
        /// <returns>
        /// The response model for the patch dsc node operation.
        /// </returns>
        public static Task<DscNodePatchResponse> PatchAsync(this IDscNodeOperations operations, string resourceGroupName, string automationAccount, DscNodePatchParameters parameters)
        {
            return operations.PatchAsync(resourceGroupName, automationAccount, parameters, CancellationToken.None);
        }
    }
}
